# -*- coding: utf-8 -*-

import os
import sys
import subprocess

from paver.easy import task, consume_args, info, needs, call_task, debug

try:
    import sett  # noqa
except ImportError:
    pass


def init(env):
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'job_offer_demo.settings.development')
    env.defaults.HTTP_WSGI_PORT = 5621


@task
def po():
    from django.core.management import call_command
    call_command('makemessages', no_location=True, ignore=[
        'venv/**', 'node_modules', 'tests', 'build', 'dist', '*.egg-info', 'envs/**', 'job_offer_demo',
    ], locale=['fr', 'en'])


@task
def mo():
    from django.core.management import call_command
    call_command('compilemessages', locale=['en', 'fr'])


@task
@needs('django_settings')
def runserver_dev(options, defaults, ROOT, which):
    """Run django runserver"""
    webpack_process = subprocess.Popen([
        which.webpack,
        '--config', ROOT.joinpath('webpack.config.js'),
        '--watch',
    ])
    try:
        call_task('runserver', args=[str(defaults.HTTP_WSGI_PORT)])
    except KeyboardInterrupt:
        pass
    finally:
        webpack_process.kill()
        rc = webpack_process.wait()
        debug('Webpack ended with %s', rc)


@task
@consume_args
def robot(ROOT, args):
    dsm = os.environ.get('ROBOT_SETTINGS_MODULE', 'job_offer_demo.settings.robot')
    info('Using %s as settings', dsm)
    os.environ['DJANGO_SETTINGS_MODULE'] = dsm
    sys.path.append(ROOT.joinpath('tests'))

    import robot
    robot.run_cli(args)


def find_version(filename):
    filepath = os.path.join(os.path.dirname(__file__), filename)
    with open(filepath, 'r') as init:
        for line in init:
            if line.startswith('__version__'):
                x, version = line.split('=', 1)
                return version.strip().strip('\'"')
        else:
            raise ValueError('Cannot find the version in {0}'.format(filename))


def parse_requirements(requirements_txt):
    requirements = []
    try:
        with open(requirements_txt, 'r') as f:
            for line in f:
                line = line.strip()
                if line.startswith('#') or not line:
                    continue
                if '://' in line:
                    continue
                if line.startswith('-'):
                    raise ValueError('Unexpected command {0} in {1}'.format(
                        line,
                        requirements_txt,
                    ))

                requirements.append(line)
        return requirements
    except IOError:
        return []


@task
def setup_options():
    import setuptools
    from paver.setuputils import setup
    readme_md = os.path.join(os.path.dirname(__file__), 'README.md')
    with open(readme_md, 'r') as readme_file:
        readme = readme_file.read()

    setup(
        name='JobOffers',
        version=find_version('job_offers/__init__.py'),
        description='Job Offers application for django',
        long_description=readme,
        author='Grégoire ROCHER',
        author_email='gregoire@emencia.com',
        packages=setuptools.find_packages(
            exclude=[
                'tests',
                'job_offers.tests',
                'job_offers.tests.*',
                'job_offer_demo',
                'job_offer_demo.*',
            ],
        ),
        include_package_data=True,
        install_requires=parse_requirements('requirements.txt'),
        zip_safe=False,
    )


try:
    import sett
    with open(sett.ROOT.joinpath('localpavement.py'), 'r') as localpavement:
        exec(localpavement.read(), locals(), globals())
except (OSError, IOError, ImportError) as e:
    pass
